@@ -12,7 +12,7 @@ from datetime import datetime, timedelta
 from itertools import zip_longest
 from colorama import init
 
-VERSION = '0.3.0'
+VERSION = '0.3.1'
 
 init()
 
@@ -290,6 +290,7 @@ def print_row(value, num_blocks, val_min, color, label=False, tail=False, doprin
         sys.stdout.write(SM_TICK)
     else:
         if color:
+            sys.stdout.write('\033[{color}m'.format(color=color)) # Start to write colorized.
             sys.stdout.write(f'\033[{color}m')  # Start to write colorized.
         for _ in range(num_blocks):
             sys.stdout.write(TICK)
@@ -372,7 +373,7 @@ def vertically(value, num_blocks, val_min, color, args):
 def print_vertical(vertical_rows, labels, color, args):
     """Print the whole vertical graph."""
     if color:
-        sys.stdout.write(f'\033[{color}m')  # Start to write colorized.
+        sys.stdout.write('\033[{color}m'.format(color=color)) # Start to write colorized.
 
     for row in vertical_rows:
         print(*row)
@@ -500,6 +501,7 @@ def print_categories(categories, colors):
        the graph."""
     for i in range(len(categories)):
         if colors:
+            sys.stdout.write('\033[{color_i}m'.format(color_i=colors[i])) # Start to write colorized.
             sys.stdout.write(f'\033[{colors[i]}m')  # Start to write colorized.
 
         sys.stdout.write(TICK + ' ' + categories[i] + '  ')
@@ -524,7 +526,7 @@ def read_data(args):
     stdin = filename == '-'
 
     if args['verbose']:
-        print(f'>> Reading data from {("stdin" if stdin else filename)}')
+        print('>> Reading data from {src}'.format(src=( "stdin" if stdin else filename )))
 
     print('')
     if args['title']:
@@ -628,13 +630,17 @@ def calendar_heatmap(data, labels, args):
                     tick = tick_3
                 elif dt_dict[day_str] > max_val * 0.25:
                     tick = tick_2
+                # show nothing if value is zero
+                elif dt_dict[day_str] == 0.0:
+                    tick = ' '
+                # show values for less than 0.25
                 else:
                     tick = tick_1
             else:
                 tick = ' '
 
             if colornum:
-                sys.stdout.write(f'\033[{colornum}m')
+                sys.stdout.write('\033[{colornum}m'.format(colornum=colornum))
 
             sys.stdout.write(tick)
             if colornum:
